@@ -34,7 +34,7 @@
  *
  */
                                                                                                           
-/* $Id: wmutil.c,v 1.4 2003/02/19 17:44:50 famao Exp $ */
+/* $Id: wmutil.c,v 1.9 2003/03/14 02:07:44 famao Exp $ */
                                                                                                           
 /* vi:set ts=4 sw=4: */
 
@@ -72,15 +72,19 @@ static Window
 _wmutil_window_tray_get_owner (GdkWindow *window) 
 {
 	Window owner;
-	Atom tray = XInternAtom (GDK_WINDOW_XDISPLAY (window),
-			"_NET_SYSTEM_TRAY_S0", TRUE);
+	char buffer[256];
+	Atom tray;
+	g_snprintf (buffer, sizeof (buffer),
+			"_NET_SYSTEM_TRAY_S%d",
+			XScreenNumberOfScreen (DefaultScreenOfDisplay (GDK_WINDOW_XDISPLAY (window)))
+		   );
+	tray = XInternAtom (GDK_WINDOW_XDISPLAY (window),
+			buffer , TRUE);
 	if (tray == None)
 		return None;
-	owner = XGetSelectionOwner (GDK_WINDOW_XDISPLAY (window),
-			tray);
+	owner = XGetSelectionOwner (GDK_WINDOW_XDISPLAY (window), tray);
 	if (!owner)
 		return None;
-	g_message ("owner found %lx", owner);
 	return owner;
 }
 
@@ -264,7 +268,7 @@ wmutil_window_workarea_ewmh (GdkWindow *window, gint *x, gint *y, gint *width, g
 		goto error;
 	
 	workarea = gdk_atom_intern ("_NET_WORKAREA", TRUE);
-	if (workarea == None)
+	if (workarea == GDK_NONE)
 		goto error;
 	if (gdk_property_get (GDK_ROOT_PARENT(),
 				workarea,
@@ -299,7 +303,7 @@ is_windowmaker_wm (void)
 	GdkAtom type_r, iswm;
 	gint format_r, length_r;
 	iswm = gdk_atom_intern ("_WINDOWMAKER_WM_PROTOCOLS", TRUE);
-	if (iswm == None)
+	if (iswm == GDK_NONE)
 		return FALSE;
 	if (gdk_property_get (GDK_ROOT_PARENT (),
 				iswm,
@@ -326,7 +330,7 @@ is_icewm_wm (void)
 {
 	GdkAtom ice;
 	ice = gdk_atom_intern ("_ICEWM_TRAY", TRUE);
-	if (ice == None)
+	if (ice == GDK_NONE)
 		return FALSE;
 	return TRUE;
 }
@@ -342,7 +346,7 @@ is_blackbox_wm (void)
 	 * to RootWindow
 	 */
 	isbb = gdk_atom_intern ("_BLACKBOX_PID", TRUE);
-	if (isbb == None)
+	if (isbb == GDK_NONE)
 		return FALSE;
 	if (gdk_property_get (GDK_ROOT_PARENT (),
 				isbb,
@@ -371,7 +375,7 @@ is_kde_wm (void)
 	GdkAtom type_r, iskde;
 	gint format_r, length_r;
 	iskde = gdk_atom_intern ("KWIN_RUNNING", TRUE);
-	if (iskde == None)
+	if (iskde == GDK_NONE)
 		return FALSE;
 	if (gdk_property_get (GDK_ROOT_PARENT (),
 				iskde,
@@ -400,7 +404,7 @@ is_gnome_wm (void)
 	GdkAtom type_r, isgnome;
 	gint format_r, length_r;
 	isgnome = gdk_atom_intern ("_WIN_SUPPORTING_WM_CHECK", TRUE);
-	if (isgnome == None)
+	if (isgnome == GDK_NONE)
 		return FALSE;
 	if (gdk_property_get (GDK_ROOT_PARENT (),
 				isgnome,
@@ -430,7 +434,7 @@ is_ewmh_wm (void)
 	GdkAtom type_r, isewmh;
 	gint format_r, length_r;
 	isewmh = gdk_atom_intern ("_NET_SUPPORTED", TRUE);
-	if (isewmh == None)
+	if (isewmh == GDK_NONE)
 		return FALSE;
 	if (gdk_property_get (GDK_ROOT_PARENT (),
 				isewmh,
@@ -458,14 +462,12 @@ can_trayed_spec (void)
 {
 	Window owner;
 	GdkAtom tray = gdk_atom_intern ("_NET_SYSTEM_TRAY_S0", TRUE);
-	if (tray == None) {
-		g_message ("tray atom not found");
+	if (tray == GDK_NONE) {
 		return FALSE;
 	}
 	owner = XGetSelectionOwner (GDK_DISPLAY (), 
 			ATOM_TO_XATOM(GDK_ROOT_PARENT(),tray));
 	if (owner) {
-		g_message ("owner found");
 		return TRUE;
 	}
 	return FALSE;
@@ -509,9 +511,8 @@ wmutil_window_tray_spec (GdkWindow *window)
 	owner = _wmutil_window_tray_get_owner (window);
 	if (owner == None)
 		return;
-	g_message ("owner found %lx", owner);
 	e.type = ClientMessage;
-	e.window = GDK_WINDOW_XWINDOW (window);
+	e.window = owner;
 	e.message_type = ATOM_TO_XATOM (window, gdk_atom_intern ("_NET_SYSTEM_TRAY_OPCODE", FALSE));
 	e.format = 32;
 	e.data.l[0] = CurrentTime;
@@ -551,7 +552,7 @@ wmutil_window_tray_baloon_start (GdkWindow *window, guint length , guint id)
 	e.type = ClientMessage;
 	e.message_type = ATOM_TO_XATOM (window, ballon);
 	e.format = 32;
-	e.window = GDK_WINDOW_XWINDOW (window);
+	e.window = owner;
 	e.data.l[0] = CurrentTime;
 	e.data.l[1] = SYSTEM_TRAY_BEGIN_MESSAGE;
 	e.data.l[2] = 0;
@@ -576,7 +577,7 @@ wmutil_window_tray_baloon_cancel (GdkWindow *window, guint id)
 	e.type = ClientMessage;
 	e.message_type = ATOM_TO_XATOM (window, ballon);
 	e.format = 32;
-	e.window = GDK_WINDOW_XWINDOW (window);
+	e.window = owner;
 	e.data.l[0] = CurrentTime;
 	e.data.l[1] = SYSTEM_TRAY_CANCEL_MESSAGE;
 	e.data.l[2] = id;
@@ -602,7 +603,7 @@ wmutil_window_tray_baloon (GdkWindow *window, const gchar *message, guint length
 		return;
 	e.type = ClientMessage;
 	e.message_type = ATOM_TO_XATOM (window, baloon);
-	e.window = GDK_WINDOW_XWINDOW (window);
+	e.window = owner;
 	e.format = 8;
 	if (length > 20)
 		actual_length = 20;
