@@ -11,7 +11,7 @@ $file->open("skk-rom-kana-base-rule-list","r") or die "Can't open\n";
 $header->open("skkconv_kana_private.h","w") or die "Can't open\n";
 
 $header->print(header_init ());
-$header->print ("base_rule_list baselist[] = {\n");
+$header->print ("SkkConvRuleItem baselist[] = {\n");
 while (my $line = $file->getline())
 {
 	my $res = "";
@@ -124,8 +124,8 @@ sub header_init ()
 #define SKKCONV_KANA_PRIVATE_H
 #include <glib.h>
 
-#include "skkconv_kana.h"
-#
+#include <skkconv_kana.h>
+
 /* This file is generated from skk.el (skk-rom-kana-base-rule-list) */
 
 EOF
